==> VR_6.2-7.tar.gz: VR/spatial/man/surf.ls.Rd <==
% file spatial/surf.ls.d copyright (C) 1994-9 W. N. Venables and B. D. Ripley
%
\name{surf.ls}
\alias{surf.ls}
\alias{deviance.trls}
\alias{df.residual.trls}
\alias{extractAIC.trls}
\alias{fitted.trls}
\alias{residuals.trls}
\title{
Fits a Trend Surface by Least-squares
}
\description{
Fits a trend surface by least-squares.
}
\usage{
surf.ls(np, x, y, z)

\method{residuals}{trls}(object, \dots)
\method{fitted}{trls}(object, \dots)
\method{deviance}{trls}(object, \dots)
\method{df.residual}{trls}(object, \dots)
\method{extractAIC}{trls}(object, k=2, \dots)
}
\arguments{
\item{np}{
degree of polynomial surface
}
\item{x}{
x coordinates or a data frame with columns \code{x}, \code{y}, \code{z}
}
\item{y}{
y coordinates
}
\item{z}{
z coordinates. Will supersede \code{x$z}
}
\item{object}{
a fit inheriting from class \code{"trls"}
}
\item{k}{
the multiple of the number of degrees of freedom to be used.
}
\item{...}{
arguments passed to or from other methods.
}}
\value{
list with components 

\item{beta}{
the coefficients
}
\item{x}{
}
\item{y}{
}
\item{z}{


and others for internal use only.
}}
\seealso{
\code{\link{trmat}}, \code{\link{surf.gls}}
}
\examples{
library(MASS)
data(topo)
topo.kr <- surf.ls(2, topo)
trsurf <- trmat(topo.kr, 0, 6.5, 0, 6.5, 50)
eqscplot(trsurf, type="n")
contour(trsurf, add=TRUE)
points(topo)


eqscplot(trsurf, type="n")
contour(trsurf, add=TRUE)
plot(topo.kr, add=TRUE)
title(xlab="Circle radius proportional to Cook's influence statistic")
}
\keyword{spatial}

==> VR_6.3-1.tar.gz: VR/spatial/man/surf.ls.Rd <==
% file spatial/surf.ls.d copyright (C) 1994-9 W. N. Venables and B. D. Ripley
%
\name{surf.ls}
\alias{surf.ls}
\alias{deviance.trls}
\alias{df.residual.trls}
\alias{extractAIC.trls}
\alias{fitted.trls}
\alias{residuals.trls}
\title{
Fits a Trend Surface by Least-squares
}
\description{
Fits a trend surface by least-squares.
}
\usage{
surf.ls(np, x, y, z)

\method{residuals}{trls}(object, \dots)
\method{fitted}{trls}(object, \dots)
\method{deviance}{trls}(object, \dots)
\method{df.residual}{trls}(object, \dots)
\method{extractAIC}{trls}(fit, scale, k=2, \dots)
}
\arguments{
\item{np}{
degree of polynomial surface
}
\item{x}{
x coordinates or a data frame with columns \code{x}, \code{y}, \code{z}
}
\item{y}{
y coordinates
}
\item{z}{
z coordinates. Will supersede \code{x$z}
}
\item{object, fit}{
a fit inheriting from class \code{"trls"}
}
\item{scale}{
unused for this method
}
\item{k}{
the multiple of the number of degrees of freedom to be used.
}
\item{...}{
arguments passed to or from other methods.
}}
\value{
list with components 

\item{beta}{
the coefficients
}
\item{x}{
}
\item{y}{
}
\item{z}{


and others for internal use only.
}}
\seealso{
\code{\link{trmat}}, \code{\link{surf.gls}}
}
\examples{
library(MASS)
data(topo)
topo.kr <- surf.ls(2, topo)
trsurf <- trmat(topo.kr, 0, 6.5, 0, 6.5, 50)
eqscplot(trsurf, type="n")
contour(trsurf, add=TRUE)
points(topo)


eqscplot(trsurf, type="n")
contour(trsurf, add=TRUE)
plot(topo.kr, add=TRUE)
title(xlab="Circle radius proportional to Cook's influence statistic")
}
\keyword{spatial}
